@@ -50,7 +50,7 @@ def _get_config(root_path='.', is_console=True, module_name='', split_error_log=
                 'encoding': 'utf8',
                 'formatter': 'verbose',
                 'when': 'midnight',
-                'backupCount': int(config('logging.handler.backup_count'))
+                'backupCount': int(config('logging.handler.backup_count', default_value=3))
             }
         }
     }
@@ -130,11 +130,6 @@ def log_debug(msg):
     _callback_log_message("DEBUG", msg)
 
 
-def log_trace(msg):
-    # TODO 内存结构保存
-    log_debug(msg)
-
-
 def log_info(msg):
     global __logger
     if __logger is None:
